All language subtitles for The.Mistress.2022.720p.BluRay.x264.AAC-[YTS.MX].ms

af Afrikaans
ak Akan
sq Albanian
am Amharic
ar Arabic
hy Armenian
az Azerbaijani
eu Basque
be Belarusian
bem Bemba
bn Bengali
bh Bihari
bs Bosnian
br Breton
bg Bulgarian
km Cambodian
ca Catalan
ceb Cebuano
chr Cherokee
ny Chichewa
zh-CN Chinese (Simplified)
zh-TW Chinese (Traditional)
co Corsican
hr Croatian
cs Czech
da Danish
nl Dutch
en English
eo Esperanto
et Estonian
ee Ewe
fo Faroese
tl Filipino
fi Finnish
fr French
fy Frisian
gaa Ga
gl Galician
ka Georgian
de German
gn Guarani
gu Gujarati
ht Haitian Creole
ha Hausa
haw Hawaiian
iw Hebrew Download
hi Hindi
hmn Hmong
hu Hungarian
is Icelandic
ig Igbo
id Indonesian
ia Interlingua
ga Irish
it Italian
ja Japanese
jw Javanese
kn Kannada
kk Kazakh
rw Kinyarwanda
rn Kirundi
kg Kongo
ko Korean
kri Krio (Sierra Leone)
ku Kurdish
ckb Kurdish (Soranî)
ky Kyrgyz
lo Laothian
la Latin
lv Latvian
ln Lingala
lt Lithuanian
loz Lozi
lg Luganda
ach Luo
lb Luxembourgish
mk Macedonian
mg Malagasy
ms Malay
ml Malayalam
mt Maltese
mi Maori
mr Marathi
mfe Mauritian Creole
mo Moldavian
mn Mongolian
my Myanmar (Burmese)
sr-ME Montenegrin
ne Nepali
pcm Nigerian Pidgin
nso Northern Sotho
no Norwegian
nn Norwegian (Nynorsk)
oc Occitan
or Oriya
om Oromo
ps Pashto
fa Persian
pl Polish
pt-BR Portuguese (Brazil)
pt Portuguese (Portugal)
pa Punjabi
qu Quechua
ro Romanian Download
rm Romansh
nyn Runyakitara
ru Russian
sm Samoan
gd Scots Gaelic
sr Serbian
sh Serbo-Croatian
st Sesotho
tn Setswana
crs Seychellois Creole
sn Shona
sd Sindhi
si Sinhalese
sk Slovak
sl Slovenian
so Somali
es Spanish Download
es-419 Spanish (Latin American)
su Sundanese
sw Swahili
sv Swedish
tg Tajik
ta Tamil
tt Tatar
te Telugu
th Thai
ti Tigrinya
to Tonga
lua Tshiluba
tum Tumbuka
tr Turkish
tk Turkmen
tw Twi
ug Uighur
uk Ukrainian
ur Urdu
uz Uzbek
vi Vietnamese
cy Welsh
wo Wolof
xh Xhosa
yi Yiddish
yo Yoruba
zu Zulu

Original subtitles

Sertai Telegram: @lubokvideo2021 - https://t.me/lubokvideo2021

Hantar permintaan/pertanyaan anda ke e-mel: lubokvideo2021@gmail.com

Sumbangan komuniti: https://sociabuzz.com/lubokvideo2021/donate

[bermain muzik yang menegangkan]

[pusingan kereta]

[bermain muzik tempo perlahan]

[muzik yang menegangkan diteruskan]

Terima kasih banyak-banyak.

Semoga berjaya.

[Madeline tergelak] Bye.

-Bonne peluang. -Terima kasih.

PARKER: Berhenti!

Hai. Yeah. [ketawa]

-[Madeline ketawa] -Berhenti.

[Parker dan Madeline ketawa]

[pintu berdebar]

[menjerit] Oh, Tuhanku.

PARKER: Argh!

[Madeline ketawa]

Satu saat.

-MADELINE: Saya sukakannya. -PARKER: Ya.

[Madeline ketawa]

MADELINE: Oh, saya faham.

Terima kasih.

Sedikit petua untuk kawan-kawan.

[Parker ketawa kecil]

[telefon berdering]

MADELINE: Parker, Saya perlukan bantuan awak dengan sesuatu.

akan datang.

[anjing menyalak]

sedia? Satu dua tiga.

Ooh. Ah. ya.

Oh, Tuhanku. Parker.

DAWN: Hai. Saya Dawn. Saya tinggal berjiran.

MADELINE: Oh, Tuhanku. Awak takutkan kami.

DAWN: Maaf, pintu awak terbuka. Saya hanya

mahu menjadi orang pertama yang mengalu-alukan anda.

Di sana, Burung Syurga.

Saya memilih mereka sendiri.

Oh, betapa manisnya. Saya Madeline.

Ini suami saya.

Masih terasa sangat pelik untuk mengatakan itu.

PARKER: Kami baru sahaja berkahwin.

DAWN: Ya Tuhanku. itu hebat. tahniah.

-Saya Parker.

-MADELINE: Siapa lelaki kecil ini? -Itu Rambo.

PARKER: Rambo? Seperti Sylvester Stallone, bukan?

Apa? Tidak. Seperti penyair Perancis.

Adakah anda seorang jurugambar? Saya melihat peralatan anda.

PARKER: Itu hanya hobi.

Nah, jika anda perlukan seorang model...

-Buatlah macam rumah sendiri.

-Uh, Parker seorang penulis, sebenarnya. Dia dalam senarai terlaris.

PARKER: Adakah. Untuk bukan fiksyen.

DAWN: Oh, baiklah. Buku apa?

Ia dipanggil Back to Normal.

Ini cerita tentang doktor haiwan

perang dengan PTSD pulang ke rumah.

Saya juga seorang penulis. saya ada blog.

Saya suka rumah ini. Ia sangat cantik.

Anda tahu, jika anda memerlukannya sebarang bantuan

menghias, saya mempunyai mata yang luar biasa. Saya

telah mereka, seperti, -semua rumah kawan saya. -MADELINE: Oh.

Itu sangat manis. Ibu saya seorang penghias, sebenarnya.

Dia akan jadi terbang dari Seattle -dalam sedikit, jadi.

-Uh-hmm.

-Kami baik. -DAWN: Adakah kamu mempunyai anak?

-Tidak, Tuhan, tidak. -Belum lagi.

DAWN: Nah, saya benar-benar baik di menjaga anak,

dan saya boleh dikatakan pengasuh sepenuh masa

semasa Kristoff berada di bandar, kerana seluruh

kumpulannya -adalah sekumpulan bayi. -PARKER: Oh, wow.

Jadi kami mempunyai bintang rock tinggal berjiran.

Oh, sukar. Mereka melawat dengan van

Dodge dengan permaidani di siling,

tetapi saya masuk video muzik terbaru

mereka, dan saya mereka semua pakaian,

jadi anda sepatutnya benar-benar menyemaknya.

Oh, anda tahu, uh, itu lucu, kerana

Madeline seorang pereka pakaian.

DAWN: Apa? Itu gila.

Kami mempunyai banyak persamaan.

Adakah awak bermain?

Eh, ia datang dengan rumah, sebenarnya.

Saya menulis muzik.

[Madeline ketawa] Oh, Tuhanku.

-PARKER: Dia melakukan semuanya. -DAWN: Ya.

-PARKER: Ancaman tiga kali ganda. -DAWN: Ya.

Saya menulis lirik dan saya menyanyi. Saya tidak memainkan sebarang

instrumen atau apa-apa, tetapi saya mempunyai beberapa demo di blog saya.

Dan anda boleh membaca tulisan saya di sana juga.

Ia adalah dawnoftime.com. Seperti, Fajar.

-Waktu Subuh-- -Hebat.

--.com. Kami pasti akan semak itu.

Adakah anda fikir ia berhantu? Saya rasa semua rumah berhantu--

Madeline agak sensitif--

---sehingga satu tahap. ---tentang perkataan-H.

DAWN: Oh, kenapa? Ia boleh menjadi perkara yang baik.

Hantu juga boleh mesra, kamu tahu.

Tambahan pula, saya sangat berhubung ke dunia roh, -dan tempat ini.

-Uh-hmm.

Sudah tentu dia.

Terdapat beberapa tenaga yang sangat baik.

Awak dah jumpa Dorothy belum?

-Dorothy? -Dorothy?

DAWN: Ya, dia berlari seperti

Persatuan Sejarah atau sesuatu.

Dia tahu segala-galanya tentang rumah-rumah lama ini.

Baiklah, kita perlu berjumpa dengannya.

Uh, Fajar, um, bukan untuk kurang ajar, tetapi

kita ada banyak pembongkaran yang perlu dilakukan.

Yeah. Tetapi terima kasih banyak-banyak kerana singgah.

Dan terima kasih untuk bunga yang cantik.

Oh, Tuhanku. kamu semua, Saya sangat teruja kerana anda berada di sini.

-Uh huh. -Serius, saya kebuluran untuk-- -

Oh. ---hubungan manusia, jadi

kita perlu minum untuk meraikan

awak -dia peramah. Selamat tinggal.

Selamat tinggal.

Dia bukan model untuk awak.

[telefon berdering]

[bermain muzik instrumental]

Pencuci mulut.

-Terima kasih. -Uh-hmm.

Kamu tahu, Saya mengambil pelajaran sebagai seorang kanak-kanak.

Adakah anda baik?

MADELINE: Oh, ia rosak hati mak

bila sedar Saya tidak mempunyai bakat.

Oh.

[bermain piano]

MADELINE: Ayah saya

pernah cakap piano tak salah not.

-Itu Monk. -Apa?

Itu sami Thelonious. Dia cakap macam tu.

Nah, mereka berdua salah.

[bermain piano]

Semakin laju jarinya melayang atas kunci, -semakin dia kagum.

-Adakah Monk itu juga?

Tidak, itu Flaubert, daripada Madame Bovary.

Baiklah, Puan Bovary main ni?

[Madeline ketawa kecil]

[bermain piano]

[tapak kaki]

[bermain muzik santai perlahan]

[tikus berdecit]

[kaca pecah]

sial. Ah.

Yesus.

PARKER: Awak kena tengok ni.

MADELINE: Apa itu?

-Ia berada di loteng. -Wah.

-Ya ampun. -Anda tahu apa ini?

Adakah mereka meninggalkan ini di sini?

Ini adalah kamera plat.

Perkara-perkara ini adalah bernilai kekayaan.

Maksud saya, ini boleh jadi milik pemilik asal.

Ini luar biasa. Adakah anda fikir ia masih berfungsi?

Kami akan mengetahuinya.

-By the way... -Yeah.

... kita ada setinggan.

-Apa? -Tikus.

MADELINE: Apa? Tidak, tidak, tidak, tidak, tidak, tidak, tidak.

[bermain muzik vintaj]

ROB:Hei, Parker. Ia Rob.

Eh, saya cuma telefon untuk menyemak dengan anda

bagaimana penulisan itu berjalan. Hubungi saya.

FRIDA: Hai, Parker Ini adalah Frida Richmond

Saya tidak mendengar khabar daripada awak sekejap.

Hubungi saya apabila anda mendapat peluang.

Terima kasih.

[bermain muzik firasat]

[percikan air]

[muzik merenung bermain]

Nabi Isa.

Hmm.

[Madeline menarik nafas dalam-dalam]

Awak kata awak berhenti.

Apa?

Anda berbau seperti asap.

Awak tahu saya perlukan sperma awak tanpa nikotin, bukan?

Ia bukan rahsia, Parker.

Kami telah berkahwin sebulan.

Dan sekarang anda akan menjadi gila beb?

Saya tidak gila bayi hanya kerana saya mahukan anak.

Kanak-kanak? Kanak-kanak?

Berapa banyak anak-anak?

Berapa banyak perkara ini awak nak?

Mulakan dengan satu, dan lihat bagaimana ia berlaku.

[bermain muzik firasat]

[dentuman]

[bermain muzik aneh]

PARKER: [menggigil]

[tercungap-cungap]

[muzik gelap bermain]

[anak ketawa]

MADELINE: Tuhan. Saya tertanya-tanya siapa dia.

PARKER: Adakah anda sedar kami

adalah orang pertama untuk melihat

ini, pernah, dalam sejarah alam semesta.

Maksud saya, perkara ini mesti ada berumur seratus tahun.

Lebih tua. Maksud saya, lihat pakaian itu.

Itulah giliran abad ini.

-Saya mempunyai satu seperti itu. -PARKER: Uh-hmm.

[telefon berdering]

Rob.

ROB:Mereka membayar anda terlebih dahulu

nampaknya, ia lebih seperti wang susu.

-[anjing menyalak] -ROB: & Lt; i & gt; Dan anda berada di belakang. & lt;

Hei, lihat, mereka mahukan sesuatu. Bolehkah anda memberi mereka sesuatu?

Rob, saya atas rahmat a--

subjek yang sangat tidak boleh dipercayai yang terus meniup saya.

ROB:Nah, mungkin lelaki ini bukan i & gt; lelaki yang betul

Tiada lelaki lain.

Lihat, saya akan mendapatkan anda sesuatu tidak lama lagi.

Percayalah.

ROB: Lihat, saya tidak akan berbohong, & lt; i & gt; mereka bimbang... & lt;

[muzik merenung bermain]

MADELINE: Awak nak pergi mana?

Saya berjumpa dengan lelaki saya.

Jadi ia akhirnya berlaku.

PARKER: Mesyuarat tidak akan selesai--

di sini, eh, kedai donat dalam, eh, Taman MacArthur.

Dia memanggilnya pejabatnya. Anda akan baik-baik saja?

Kamu tahu Saya agak ketakutan.

Oh tolonglah.

Ambil sahaja yang boleh dimakan atau minum sesuatu untuk berehat.

-Saya akan jumpa awak nanti. -Semoga berjaya.

-Terima kasih. -Saya sayang awak.

Saya cintakan awak juga.

[pintu ditutup]

[bermain muzik jahat]

[pusingan kereta]

PARKER: Ah.

[merengus]

[bermain muzik jazz]

-LELAKI: Ayuh. -[bualan tidak jelas]

DAVEY: Baiklah. Mudah.

Raja Carole, Burt Bacharach, atau

Nyro, Marvin Hamlisch, Jimmy Webb.

Ini, eh, Dylan, Springsteen, itu senarai

yang sangat anemia yang anda ada di sana.

Nah, anda tahu...

Ya, saya terkejut anda meninggalkan diri anda daripadanya.

-Ah. -[Parker ketawa]

Dia begitu merendah diri.

-Anda mendapat semuanya... -Bagaimana dengan The Beatles?

[ketawa]

siapa awak

Saya fikir anda adalah mengadakan pesta.

Tidak tidak tidak.

Tidak, ini, eh, ini sedikit perkara suai rumah.

Ia hanya sepasang kawan.

Um, ini Dawn, dia--um,

dia tinggal di sebelah.

Dia, eh, macam-macam

jawatankuasa penyambut kejiranan.

-Uh-hmm. Baik. -Ini Rob, dia ejen saya.

Saya di luar jam, hanya Rob.

-[ketawa] -Hai, Hanya Rob.

Hanya Rob. Itulah Davey.

Davey Burt, pencipta lagu terkenal.

-Itulah saya. -DAWN: Ya.

Lagu anda Ingat Bila adalah satu lagu kegemaran saya.

Ayuh, nak. Anda tidak tahu Ingat Bila.

-Tidak, saya serius. -Berapakah umur kamu?

-Sangat biadap. -Berapakah umur kamu?

JANINE: Perempuan, Saya tidak boleh mengatasi rumah ini.

Berapa banyak bilik tidur? Tiga bilik tidur.

Salah satunya ialah Parker pejabat,

walaupun, dan yang lain ialah bilik tetamu.

Maksud anda taska?

-Kita akan lihat. -[ketawa]

Nah, perempuan, anda perlu melakukannya sebelum umur 40.

Yesus. Adakah anda pakar kesuburan?

Apa yang saya katakan sekarang anda boleh membatalkan pelan sandaran anda.

Maksud saya, apa yang awak akan lakukan dengan semua telur yang anda bekukan?

-Buat telur dadar $14,000? -[ketawa]

Tuhan, dia bermain.

-Oh, mari kita pergi melihat. -Ayuh.

Yeah.

DAWN: ♪ Daun musim luruh sekitar ♪

♪ Ia adalah siluet sepanjang kaki lima -♪

DAVEY: Hebat.

SUBUH: ♪ Ingat bila bulan ♪

♪ Saya berdoa ♪

♪ Mencatatnya ke masa yang tepat ♪

♪ Dan bermain ♪

Serius?

DAWN: ♪ Ia adalah kali terakhir Saya melihat muka anda ♪

♪ Ia adalah kali terakhir Saya nampak muka awak ♪

[bermain muzik instrumental]

DAVEY: Mereka memberi anda kemajuan besar pada buku.

-Bagaimana keadaannya? -Permulaan perlahan.

Tindakan ini telah menyebalkan semua kehidupan daripada saya.

Hmm.

Tetapi saya akhirnya bertemu dengan subjek saya.

Sejuk.

Dan, lelaki, kisah-kisahnya menakjubkan.

Di manakah anda mencari lelaki ini?

Ia seperti anda seorang--

anda adalah magnet untuk serius individu yang rosak.

Nah, cerita-cerita yang perlu diberitahu oleh seseorang.

Lelaki, lelaki, lelaki.

Hey.

-Malam yang menyeronokkan. -Awak pergi?

Yeah. Saya perlu pergi. Kena pergi jalan Rambo.

Tetapi serius, parti yang luar biasa.

-Ikonik. -Hmm.

-Dan kamu-- -Hey.

--- lagenda yang gila. -Anda adalah legenda.

Anda membunuhnya. Anda membunuhnya pada piano itu.

Uh-hmm.

[mengeluh] Ooh. Ooh.

Dan dengan cara itu, lelaki itu, Rob, ejen

awak, saya rasa dia akan menandatangani saya.

-Oh. -Jadi terima kasih.

-Malam. -Mari kita lakukan ini lagi.

Tidak lama kemudian.

Ia adalah kejiranan yang bagus.

[Parker ketawa kecil]

Siapa itu?

Apa? Oh. tiada apa.

tiada apa.

Kenapa awak nampak macam anda hanya membuang seluar anda?

Hey.

Bolehkah saya memberitahu anda sesuatu?

Yeah sudah tentu.

Saya tahu bahawa anda adalah kawan dengan Maddy

sebelum saya tetapi saya rasa seperti kita telah mendapat hampir.

DAVEY: Maksud saya, awak, seperti, satu-satunya kawan saya sekarang.

Pergi. Berikannya.

Baiklah. [ketawa]

Ada--uh, [mengeluh]

baiklah.

Jadi sebelum Maddy, ada wanita ini.

DAVEY: Uh-hmm.

Ia tidak bertahan lama, hanya beberapa

tarikh, tetapi ia tidak berakhir dengan baik.

-DAVEY: Hmm, adakah ia pernah? -Tidak, saya serius.

Ini benar-benar teruk.

Saya maksudkan, ia bermula dengan panggilan

telefon dan kemudian-- dan kemudian menghantar

mesej tanpa henti, maka saya menukar nombor saya, kan?

DAVEY: Uh-hmm.

Tetapi dia mencari jalan untuk mengatasinya.

Dan kemudian pada suatu malam, saya

melihat dia duduk di luar apartmen

saya di dalam keretanya hanya menunggu.

-DAVEY: Tidak. -Yeah.

Jadi, eh, maksud saya, saya panggil polis.

DAVEY: Uh-hmm.

Tetapi apabila mereka

sampai di sana, dia sudah tiada.

Dan ini terus berlaku setiap malam selama

berminggu-minggu dan polis mula berfikir bahawa saya gila.

-[Davey tergelak] -Yeah.

Tetapi pada suatu malam, saya pulang ke rumah...

dan dia ada di apartmen saya,

bersembunyi di bawah katil saya.

DAVEY: Yesus Kristus.

Jadi, ya, mereka akhirnya kurung dia di 5150.

-Adakah anda tahu apa itu? -DAVEY: Tidak.

Di situlah mereka boleh mengekalkan anda di wad jiwa selama 72 jam.

DAVEY: Ah.

Mereka akhirnya menyimpannya untuk sebulan.

-DAVEY: Persetan. -Yeah.

Jadi saya mendapat perintah larangan dan terakhir

saya mendengar, emm, dia telah berpindah sesuatu tempat.

Lihat, anda tidak boleh menyebut ini kepada Janine, tolong?

-Jadi Maddy tidak tahu? -Tidak, dia tahu tentang dia.

Dia hanya tidak tahu bahawa saya...

Itu apa?

Saya fikir dia mungkin kembali.

Oh, saya sayang jiran awak.

Dia, eh, sangat berbakat.

Nabi Isa.

Ia seperti menjadi dalam hati yang berdegup kencang.

PARKER: Itulah ideanya.

Yeah.

Jadi, eh, lihat, eh, saya tahu ini

bukan masanya atau tempat dan anda

sudah mendapat isteri, jadi anda

tidak perlu niat jahat di rumah awak.

Rob.

Ini adalah perkara yang terbaik Saya pernah menulis.

Beri saya masa seminggu.

[mengetuk pintu]

DAVEY: Hei, saya mahu lawatan!

Saya terpaksa pergi juga.

Baiklah. Saya akan hubungi awak.

-Baik. -Baiklah.

DAVEY: Ini adalah tembakan wang.

PARKER: Ia agak bagus, bukan?

DAVEY: Lelaki, Saya suka bawa Janine ke sini.

PARKER: Saya tidak fikir kami -untuk rancangan seks

secara langsung, tetapi anda boleh bekerja pada--ow!

Rumah ini, perkara terus runtuh.

DAVEY: Sial, lelaki. Ada sesuatu dalam tu.

-Hmm. -PARKER: Berhati-hati.

Ada janda hitam sekitar sini.

Ah! sial!

-Ah! -Anda bodoh.

[ketawa] Faham.

Tidak, sebenarnya, lelaki, ada sebuah kotak di sini.

Apa?

[Davey merengus]

apa?

Kami terus mencari semua ini benda pelik dalam rumah ni.

Apa itu?

Surat, kawan.

Ada seperti fucking 50 daripadanya

di sini, semuanya kepada William.

"William sayangku.

Satu minit sahaja telah berlalu sejak

anda mencium saya selamat malam dan

aroma bay rum memenuhi lubang hidung

saya dan mengaburkan fikiran saya."

Barang berair.

Seperti Victorian Penthouse forum.

Tunggu sekejap. Siapa William?

Lelaki yang membina rumah ini, namanya ialah William Woodruff.

-Apa? -JANINE: Baiklah.

Nah, teruskan membaca.

Um, okay.

"Anda meletuskan semangat dalam

diri saya yang menyaingi Vesuvius.

Adakah itu metafora untuk orgasme?

-DAVEY: Saya sayang mereka. -JANINE: Uh-hmm. [ketawa]

MADELINE: "Walaupun hidup kita lautan terpisah,

saya tertarik kepada awak seperti kapal ke rumah api.

Seolah-olah jiwa kita ditakdirkan untuk bersatu.

Oh, William, Saya tidak memerlukan makanan

atau air jika saya boleh rasa bibir anda lagi.

Sehingga itu, bunga

kehausanmu, Rebecca."

JANINE: Itu cukup dalam.

-DAVEY: Hmm. -Hmm.

-Jalan untuk pergi, William. -[ketawa]

Itu surat cinta.

Awak tak pernah tulis saya sebarang surat cinta.

Dan anda tahu apa? Gambar batang tidak dikira.

Oh, untuk William?

Oh, sial. Saya terlupa hadiah pindah rumah awak.

-Ay, awak tak dapat hadiah kami? -Saya telah lakukan.

PARKER: Lekatkan itu.

JANINE: Saya betul- berada di rumah ini...

-PARKER: Ia berfungsi. -DAVEY: Oh, tidak. memang bagus.

Cuba--di mana... Saya rasa ini.

Oh.

MADELINE: Berapa banyak yang

[anda fikirkan benda ni - calar fonograf]

Ia dihidupkan.

LELAKI: & lt; i & gt; Di dalam cangkerang pain, & lt;

dinyanyikan oleh Artemis - dalam rekodnya sendiri.

[bermain muzik vintaj]

MADELINE: [mengeluh]

Saya bersedia untuk kerja.

Oh, ya?

komersial Mercedes.

Oh.

Wang itu bagus, tetapi ia adalah kematian kreatif.

Kreativiti terlalu dinilai.

[Madeline ketawa]

Ambil wang anda dan lari.

MADELINE: Saya rasa kita patut membaca satu setiap malam.

Mungkin seperti cliffhangers

kecil, seperti novel-novel itu

ditulis dalam huruf, apakah namanya?

Epistolary.

Ugh. Saya tidak sabar untuk menunjukkan kepada ibu saya.

Dia akan sangat teruja.

Maksud saya, bolehkah awak percaya kami menjumpai ini?

Sungguh keren.

Berapa lama dahulu adakah mereka telah ditulis?

Oh, ini akan membuat podcast yang hebat.

Saya benar-benar boleh membayangkannya pada NPR.

Apa pendapat kamu?

[muzik gelap bermain]

Hello?

Apa?

awak buat apa?

apa salahnya

tiada apa. Saya, eh, akan mengurung.

Baik.

[muzik merenung bermain]

[suis lampu klik]

[pintu dihempas kuat]

[ayunan berderit]

-Dan anda fikir saya paranoid? -[ketawa]

Saya selalu tidur dengan

kayu besbol di sebelah katil.

-Uh huh. -Ia adalah--ya, kekuatan tabiat.

-[Madeline ketawa kecil] -Apa?

Saya ada mesyuarat awal pagi.

-Baik. -Saya akan tidur.

Baik.

[ketawa] Saya sayang awak.

Saya cintakan awak juga.

[bermain muzik jahat]

MADELINE: & lt; i & gt; "William

sayangku, & lt;; berlambak di tepi pantai.

Ia mencecah pasir hanya untuk bergolek kembali ke laut.

Tetapi apabila ia mendapati cinta

orang lain, air bertemu dan

bercampur, dan menjadi satu lautan yang dalam.

Dan jika saya memotong urat, anda akan mengalir keluar.

Dalam hati saya, Saya tahu awak rasa yang sama.

Boleh dinding yang memisahkan kita, runtuh.

Bunga terapung awak, Rebecca."

[bermain muzik yang menaikkan semangat]

[Parker bertepuk tangan]

-[Madeline ketawa] -Balik sikit.

Di situ.

Sempurna.

[ketawa] Oh, Tuhanku.

Korset tu betul-betul nombor di belakang anda.

Hmm, sedap rasanya.

Hei, pada pendapat anda apakah

maksudnya "dinding yang memisahkan kita?"

Dinding masyarakat?

Um, maksud saya, mereka orang Victoria.

Ia tidak mudah untuk dating ketika itu.

Saya fikir ia adalah metafora.

Saya rasa dia maksudkan sesuatu yang lain.

-Hei, kenapa awak berhenti? -[ayunan berderit]

[bermain muzik jahat]

-Hubungi 911. -Apa?

PARKER: Maddy, buat sahaja! Hubungi 911!

-Hubungi 911! -Apa?

Kekal di sana!

[bermain muzik sci-fi]

[talian telefon berdering]

PENGHANTARAN: 911, apa kecemasan anda, tolong?

Eh, kita berayun ke belakang, dia duduk di atasnya, -dan kemudian dia menghilang.

-COP 1: Hilang?

-Seperti hantu? -Tidak. Apa?

Tidak. Eh, saya hilang pandangan dia.

Dan anda menghubungi 911 untuk--

Dia ada stalker.

Apa?

Ia adalah setahun yang lalu.

Baik. Dia mempunyai perintah larangan.

COP 1: Adakah dia?

saya tak tahu. Saya tidak dapat melihat wajahnya.

Adakah anda melihatnya?

Anda mempunyai perintah sekatan?

Saya sudi. ya. Ia di pejabat saya.

COP 1: Tunggu. Jika anda tidak boleh ID dia, tidak ada gunanya.

Apa nama dia?

Gina Santorelli.

COP 1: Beritahu anda apa. Kami akan bersiar-siar,

memeriksa kawasan kejiranan. Itu sahaja yang boleh kita lakukan.

Mungkin gadis mabuk daripada bar.

[kereta bermula]

[hon]

-Adakah dia? -Saya tidak tahu.

Saya rasa tidak sihat.

Saya minta maaf.

Bagaimana anda tidak tahu dia gila?

[muzik gelap bermain]

[celoteh yang tidak jelas]

[muzik gelap diteruskan]

PARKER: Anda tahu bagaimana PTSD berfungsi?

Ia adalah periuk perlahan. Ia seperti tumor.

Ia bernanah dalam diri anda berbulan-bulan, kadang-kadang bertahun-tahun

Kadang-kadang anda tidak melakukannya perasan la.

Tetapi apabila anda akhirnya

melakukannya, ia sudah terlambat.

Ia telah berakar umbi dan

ia memakan anda hidup-hidup.

Saya fikir saya boleh meninggalkannya semua di belakang.

Dan ini boleh jadi permulaan baru.

Ia adalah.

Ia adalah.

Untuk kita berdua.

Anda fikir saya tidak mempunyai bahagian trauma saya yang saksama?

Cuba menjadi wanita kulit hitam di dunia ini.

[tergelak kecil]

Saya telah kacau dan gaslit sehingga

banyak kali saya boleh menyala Jalan itu.

PARKER: [ketawa]

MADELINE:Tetapi kami bersama-sama sekarang

Tiada apa yang akan mengubahnya.

[klik papan kekunci]

[bermain muzik jahat]

[muzik jahat diteruskan]

[guruh berdentum]

[merengus]

[klik papan kekunci]

[pintu berderit]

[guruh berdentum]

[klik papan kekunci]

[bermain gramofon]

[guruh berdentum]

[bermain gramofon]

[guruh berdentum]

[muzik yang meriah]

[pintu berderit]

[bermain muzik jahat]

[guruh berdentum]

[merengus]

[muzik jahat diteruskan]

MADELINE: Parker?

Adakah anda di bawah sana?

-Bolehkah awak datang ke katil? -[slam tingkap]

MADELINE: Ribut sedang menggerunkan saya.

Tolong?

Saya akan bangun.

[bermain muzik termenung]

-[pintu kereta dihempas] -PARKER: Biasalah.

terima kasih.

[klik papan kekunci]

PARKER: Rob, saya hanya mahu panggil awak.

ROB:Tolong beritahu saya anda ada sesuatu

PARKER: Lelaki saya akhirnya datang melalui.

Saya mempunyai 30 muka surat pertama.

ROB:Oh, terima kasih Tuhan.

Bilakah anda boleh mendapatkannya kepada saya?

Nanti saya telefon awak, ya?

ROB: Saya boleh membuat ganda

PARKER: Baiklah. Jumpa lagi. Selamat tinggal.

FRIDA: Hai, Parker

Ini Frida Richmond lagi.

Saya tidak tahu sama ada anda luar bandar atau apa.

Tetapi saya benar-benar memerlukan untuk bercakap dengan anda.

Hubungi saya. Terima kasih.

JANINE:William yang dihormati oleh & Lt; i & gt; nasib

semata-mata kebetulan, & lt; i & gt; Saya melihat anda hari ini.

Seperti yang saya beli oren dari para petani di Bukit

Bunker, saya nampak kepala anda yang tinggi di atas orang ramai.

Bayangkan kejutan saya untuk

melihat anda kembali dari San Francisco.

Dalam keterujaan saya, Saya hampir

menjerit nama awak, dan betapa

skandalnya saya memakai pakaian itu

anda membeli saya dengan sulaman yang indah.

Tidak hairanlah anda seronok pakaian saya

apabila berhadapan dengannya bentuk matronly.

Sayang sayang, membesarkan anak telah mengambil tolnya.

Tetapi saya milik awak, William,

walaupun awak hanya separuh milik saya.

Bunga sabar awak Rebecca.

kamu semua.

William sedang menjalin hubungan sulit.

Dinding yang memisahkan kita. Ayuh.

Itulah isterinya, anaknya.

Rebecca, perempuan simpanan.

JANINE: Baiklah. Pertama sekali, -William ialah seorang pemain.

-[ketawa]

DAVEY: Ini tidak akan berlaku berakhir dengan baik.

Dia memakai gaun itu bahawa dia

membelinya yang kebetulan melihatnya?

Mereka berjumpa di sebuah pasar.

Dia tidak menulisnya kembali. Dia tidak memberitahunya -dia ada di bandar?

-Tidak tidak.

Saya bersama Davey. Saya bersama Davey.

-Dia seorang penguntit.

-Saya rasa itulah sikap sinis anda yang moden. -Ia bukan sinis, kawan.

-Ini bukan kebetulan. -Dia boleh menulis dia.

Dia boleh memberitahunya itu dia tidak mahu bersamanya.

Dia bukan. Jadi nampaknya seperti dia sedang menimangnya.

Parker betul. Dia jelas muda dan terdedah.

Dia harus berkomunikasi.

Baik. Lelaki, lelaki, Saya tidak suka untuk memberitahu

anda, tetapi Rebecca sayang kami gila kelawar.

-Uh huh. -Saya terpaksa mengambil kebocoran.

Oh saya juga.

-Saya akan pergi ke atas. -Tidak tidak. Hei, saya faham.

Lihat, saya perlukan latihan.

Dia gila.

[tergelak kecil]

Maksud saya, najis ini gila.

Secara literal.

Maksud saya, dia mendapat tulisan yang bagus.

[tergelak kecil]

JANINE: Ya Allah. Saya perlukan minuman.

[tandas siram]

Hello?

-[muzik tegang dimainkan] -[merengus]

[muzik tegang diteruskan]

-[menjerit] -JANINE: Oh, Tuhanku, Davey.

-PARKER: Oh, Tuhanku.

-Parker, -PARKER: Apa yang berlaku? -panggil ambulans.

JANINE: Hubungi 911. Hubungi 911. Davey.

-Davey, bangun! -MADELINE: Janine, tidak, tidak, tidak.

JANINE: Ya Tuhanku. Saya tidak tahu sama ada dia bernafas.

MADELINE: Baiklah. Dia masih bernafas.

-Ia akan menjadi baik. -JANINE: Davey, bangun!

PENGHANTARAN:911, apa awak kecemasan?

-JANINE: Davey! -Baik.

Baik, teruskan kami kemas kini, okay?

Baik. Selamat Malam.

[mengeluh] Hmm.

Davey masih di hospital.

Mereka menahannya semalaman.

PARKER: Adakah dia akan baik-baik saja?

Ambil satu daripada ini.

-Oh, apa ini? -An Ambien.

Ia akan membantu anda tidur, okay?

-Itupun dia. -Hmm.

[mengeluh]

Tangga itu khianat.

Kami akan lakukan sesuatu tentang itu.

Baik.

saya sayang awak.

saya sayang awak.

[lantai berkeriut]

REBECCA: ♪ Kami merayau melalui bayang-bayang pain ♪

♪ Cinta saya dan saya ♪

♪ Semasa angin bertiup ♪

♪ Baru dari laut ♪

♪ Dan bayang itu datang di antara ♪

♪ Cinta saya dan saya ♪

[bermain muzik jahat]

Datang.

Saya tidak gila.

-[mengerang] -[tercungap-cungap]

[muzik jahat diteruskan]

Ini tidak boleh menjadi nyata.

-[tercungap-cungap] -[mengerang]

Ini tidak boleh--

-ini tidak boleh menjadi nyata. -[mengerang]

-[mengerang] -[tercungap-cungap]

[tercungap-cungap]

DAVEY: Saya kelaparan Adakah anda akan membuat saya sandwic?

JANINE: Macam mana rupa saya pembantu rumah? Saya akan tolong awak.

-Apa-apa sahajalah. [ketawa] -Kami akan membuat orang itu sandwic.

Dia lebam dan pemarah, jadi...

saya sayang awak.

Lelaki, awak takut daripada kita.

[merengus]

PANGKAT PROFESOR:Umat Manusia & Lt;

i & gt; sedang menunggu untuk Mesiah, tetapi

untuk Jerman, Mesiah bukanlah Putera Damai.

Lihat, kawan, saya tahu saya bukan orangnya saksi yang paling

boleh dipercayai sekarang, tetapi saya bersumpah demi Tuhan, sesuatu--

PROFESSOR RANKIN:Lagi Hitler

--pukul saya.

PARKER: Davey, saya maksudkan awak sahaja jatuh sangat teruk.

Saya tidak jatuh sendiri.

Saya rasa dia ada di rumah awak.

-PARKER: Siapa? -Apa maksud awak siapa?

Penguntit awak.

Anda perlu--anda perlu pergi balik sana sekarang.

Anda perlu--anda perlu menyemak

semua atas, atas ke bawah. Sialan, kawan.

Persetankan ia. Saya harap ia--

Saya harap ia tidak benar, tetapi di sini.

-PARKER: Uh-hmm. -DAVEY: Dapatkan ini.

Tolong saya.

Berikan saya kotak itu.

Oh.

-Apakah itu? -Ia adalah .9 milimeter.

-Ambil ini. -Tidak. Tidak, tidak, tidak, -Saya

tidak mengambil pistol. -Bagaimana jika saya betul?

Bagaimana jika ada seseorang di rumah anda?

Bagaimana jika masih ada seseorang di rumah anda?

-Anda perlu pergi melihat. -[mengeluh]

Baik. Lihat, lelaki, Janine berkata saya kena berjaga 24 jam.

Itu alasan yang tepat untuk Maddy tinggal di sini.

Lindungi keluarga anda.

REBECCA: Dear William, malam tadi

saya berdiri di luar rumah anda.

Lampu menyala di dalam bilik kerja

awak, dan saya tahu awak sudah terjaga.

Saya boleh menekan loceng anda, jari

saya hanya beberapa inci daripadanya.

MADELINE:Anda akan mempunyai & Lt; i & gt;

menjawab pintu, & lt; i & gt; isteri anda sedang tidur nyenyak.

Anda akan melihat wajah saya, dan saya milik awak.

REBECCA: Dan anda akan telah & Lt; i & gt; tidak diampunkan marah dengan saya

MADELINE: Dalam itu masa ribut yang saya

boleh sabotaj semua yang saya sayangi

hanya untuk memiliki perhatian anda seketika.

Kenapa awak tak balas?

Keputusasaan saya adalah hasil anda...

Rebecca.

Ia sangat sedih.

[muzik merenung bermain]

-DAWN: Hai. -Hai.

DAWN: Saya nampak lampu awak menyala. Saya fikir

anda mungkin - mengadakan parti lain, bukan? -Tidak.

DAWN: Adakah anda lakukan apa-apa yang menyeronokkan?

Maksud saya saya sedikit-- sibuk sikit sekarang ni.

DAWN: Dengar, rancangan saya gagal dan

saya tidak dapat mencari corkscrew saya

dan saya tidak suka minum seorang diri.

Adakah ada peluang yang anda mahu hanya minum dengan saya?

Saya serius akan layu dan mati di apartmen saya.

Seperti, saya akan selesai esok kalau awak tak lepak dengan saya.

Saya perlu bergaul dengan seseorang.

-Baik. Masuklah. -DAWN: Okay.

-Terima kasih. -[cengkerik berkicauan]

Madeline tinggal bersama beberapa kawan malam ini.

-Oh. -Saya baru nak buat kerja.

Oh, adakah anda mahu saya membukanya?

Hanya jika anda akan meminumnya.

Baiklah. Saya boleh menggunakan sesuatu yang lebih keras.

Saya suka sesuatu yang kaku.

Oops, itu tidak betul. [ketawa]

Saya akan mempunyai apa sahaja yang anda miliki.

-PARKER: Bourbon okay? -Bourbon cantik.

terima kasih.

Ini sedang melihat kamu, nak.

-[kaca berdenting] -Itu dari Casablanca.

Ia filem lama.

Adakah anda pernah tertanya-tanya bagaimana

keadaannya, seperti, hidup dalam warna hitam dan putih?

Saya memikirkannya sepanjang masa.

Ia jauh lebih glamor.

Saya suka rekod awak.

Anda harus memakai satu.

PENYANYI: ♪ Saya masih ingat ♪

Di manakah anda mendapat perabot?

Oh, saya tidak tahu, di mana-mana.

Saya membaca buku awak.

Awak buat?

Wah.

Saya menangis.

Ia menyayat hati, cantik.

Terima kasih.

Um, jadi kenapa masa yang teruk?

-[ketawa] -Apa?

DAWN: Awak kata begitu masa yang teruk, kenapa?

Oh, panjang ceritanya.

Anda boleh memberitahu saya apa sahaja, kamu tahu.

Saya boleh simpan rahsia.

Adakah anda pernah tertanya-tanya

di mana silap anda dalam hidup?

Seperti, jika anda boleh kembali

ke saat itu di mana anda keluar

dari landasan dan hanya membetulkannya?

Jika saya terpaksa hidup sepanjang hidup saya

berulang lagi, saya akan melakukan semua kesilapan

yang sama hanya lebih awal, Tallulah Bankhead berkata demikian.

Dia seorang pelakon.

Jadi, apa masa anda?

Saya berumur 12 tahun,

melepak dengan

beberapa kawan,

membaling telur ke

arah kereta dari jejantas ke lebuh raya.

Dan kanak-kanak ini,

Derrick Bush, dia

mengambil batu besar ini

dan dia berani saya membuangnya.

Dan saya berkata tidak.

Tetapi dia telah membeli burger saya hari itu dan dia berkata jika

saya melakukannya Saya tidak perlu membayar balik kepadanya.

Jadi saya buat.

Ia melalui cermin depan

dan lelaki itu tergelincir ke tepi jalan dan ke sebatang pokok.

Saya masih ingat bunyi itu.

Ia seperti nahas kapal terbang, seperti bom meletus.

Dan itu sahaja.

Dan kami, um...

kami melarikan diri dan kami tidak

pernah bercakap mengenainya lagi...

sehingga kini.

Kanak-kanak melakukan perkara bodoh.

Begitulah caranya dengan kanak-kanak.

Adakah lelaki itu baik-baik saja?

Jadi, ya, jika saya boleh kembali, saya akan

membayar untuk makan tengah hari saya sendiri.

Jika saya boleh kembali, saya akan peluk budak kecik tu.

Saya yakin itu sahaja yang dia perlukan.

[tergelak kecil]

Saya perlu memberitahu anda sesuatu, Saya tidak...

sangat baik dengan godaan.

DAWN: Saya juga tidak.

Saya akan kembali sebentar lagi.

Baik.

[laci ditutup]

[air memancar]

[tukar klik]

[dentingan logam]

Hello?

Parker?

Hey.

awak buat apa kat sini?

-[berdentum] -[mengerang]

-[berdentum] -[Fajar mengerang]

Anda lihat, saya tidak pernah menjadi baik

dengan godaan kerana saya tidak pernah

menjadi baik dengan wanita, itulah sebabnya--Subuh?

Hello?

Subuh?

[bermain muzik jahat]

[tercungap-cungap]

[menangis]

Tidak tidak tidak Tidak.

Tidak, tidak, tidak, tidak, tidak.

[tercungap-cungap]

Nabi Isa. Nabi Isa. Nabi Isa.

Oh tidak.

Oh, sial, sial.

Oh, Tuhanku. Oh, Tuhanku. Oh, Tuhanku.

[nada dail bip]

[telefon berdering]

PENGHANTARAN: 911, apa kecemasan anda?

[retches]

[api berbunyi]

[tangga berderit]

[bermain muzik ngeri]

Awak dah hancurkan hidup saya.

Sayang, Parker yang manis.

Saya adalah hidup awak.

PENYANYI: ♪ Kami merayau melalui bayang-bayang pain ♪

♪ Cinta saya dan saya ♪

♪ Semasa angin bertiup ♪

♪ Baru dari laut ♪

♪ Apabila tiba-tiba kegelapan yang cergas mencuri ♪

♪ Merentasi langit musim panas ♪

♪ Dan bayang itu datang di antara ♪

♪ Cinta saya dan saya ♪

[bermain muzik jahat]

[anjing menyalak]

Apa kejadahnya, Parker?

Sekurang-kurangnya saya tidak menyembunyikannya.

[mengeluh]

mana peknya?

Berikan mereka kepada saya.

Madeline, saya ada malam yang sangat teruk.

Saya tidak mahu mendengarnya.

Awak beritahu saya awak berhenti.

Ini berhenti sekarang.

[tapak kaki]

[Madeline menjerit]

[menangis teresak-esak]

Apakah ini?

Dia berada di rumah kami, Parker.

[menangis teresak-esak]

Oh tidak.

[tapak kaki]

MADELINE: Tidak!

[menangis teresak-esak]

Saya tidak boleh hidup seperti ini.

Awak kata dia sudah tiada.

Dia ada di rumah kami.

Panggil polis.

Saya mahu dia ditangkap.

Awak mulakan ini.

Awak kena hentikan!

Hubungi polis, Parker!

[hon kereta berbunyi]

[tercungap-cungap]

Oh, Tuhanku.

Ia sangat cantik.

Tinggalkan mereka di sini.

Oh!

Sayang.

Hei, ibu.

Hello, Parker.

Berikan saya pelukan. sayang.

Kamu semua,

lihatlah.

Saya tersepit antara dua penjahat besar ini.

Sudah tentu, ia adalah besar sebagai Volkswagen.

Dan mereka menyebar seperti mereka bersalin.

Dan kemudian--oh, Tuhan!

Teksi itu berbau seperti rumah sembelih dan saya

mempunyai kepala saya di luar seperti Saint Bernard.

Oh, indah.

[terkejut] Ia seperti anda semua telah tinggal di sini selama bertahun-tahun.

Oh, saya mempunyai banyak idea.

Awak tahu, saya nak pergi ke setiap

kedai antik dan pasar lambak di bandar.

Maksud saya, saya rasa kita patut bersenang-senang dengan perkara

Victoria dan campurkan beberapa perkara pertengahan abad--anda tahu.

Kami tidak mahu rumah itu untuk kelihatan seperti muzium,

atau berhantu, atau lebih teruk, seperti beberapa

pembantu rumah tua tinggal di sini dengan kucingnya.

Di mana bilik air?

MADELINE: Oh, ia baru sahaja selesai, hanya melalui sana.

Hah. Oh! Piano.

Semua orang mesti mempunyai piano di rumah

mereka walaupun anda bermain seperti Maddy.

Anda tidak pernah tahu, Herbie

Hancock boleh datang untuk makan malam.

PARKER: Saya akan letak beg anda di tingkat atas.

EVELYN: Oh. Terima kasih, Parker.

Saya tidak percaya saya terlupa dia datang.

Dia tidak boleh tahu tentang mana-mana perkara ini.

-Maddy. -Sebaik sahaja kita pergi--

-Maddy, kami tidak tahu-- ---panggil polis sialan.

-Kami tidak tahu sama ada itu dia. -Dan minta dia ditangkap.

-Pintu terbuka. -Atau untuk menekan caj.

-Ia boleh jadi sesiapa sahaja. -Kami tahu siapa--

anda tahu betul siapa itu.

[mesin berputar]

EVELYN: & Lt; i & gt; Anda tahu, & lt; & Lt; i & gt;

Saya berfikir, kita harus pergi ke pasar lambak di Melrose.

Anda tahu yang satu oleh sekolah menengah?

-Uh huh. -Adakah Melrose?

Yeah. Yeah.

-Kita boleh melakukannya. -[enjin dihidupkan]

EVELYN: Kerana saya fikir kami telah merindui Rose Bowl.

Saya rasa itu sahaja pada waktu pagi.

MADELINE: Ya.

[pusingan kereta]

[muzik merenung bermain]

EVELYN: Licorice. Adakah anda tahu i & gt; likuoris itu boleh membunuh anda?

Adakah anda tahu bahawa? Ia membawa maut.

Ia boleh memberi anda kegagalan jantung.

Parker, jangan makan licorice.

Oh, Parker sudah cukup tabiat buruk.

Anda masih tidak merokok, Adakah awak?

Dia berhenti. Betul, sayang?

Bagaimana buku anda datang, Parker?

Hmm.

Baik.

-Ya, ia akan datang. -Hmm.

Anda tidak akan menulis sesuatu menyedihkan, adakah anda?

Maksud saya, kenapa anda tidak menulis sesuatu yang menaikkan semangat?

Anda mungkin akan dibayar lebih.

-MADELINE: Ibu? -[ketawa]

Dia mungkin betul, tetapi...

seperti yang mereka katakan, tulis apa yang anda tahu.

Adakah anda tahu betapa sukarnya untuk diterbitkan, Ibu?

Parker dalam senarai terlaris senarai.

Saya tahu. Saya dah baca ia.

Ianya indah.

Ia sangat menyedihkan.

Parker melakukan temu bualnya di kedai donat.

-Betul ke? -[Madeline ketawa]

Ia membebankan saya sandwic telur

dan keju dan coklat kuno, tapi...

kisah-kisahnya menakjubkan.

Dan dia tidak tertekan atau menyedihkan.

dia...

Sebenarnya dia kelakar dan pandai.

Dan dia tinggal dalam khemah di bawah lebuh

raya dan dia membuang sampah untuk makanannya.

Tetapi dia masih berjaya mencari kecantikan dan humor dalam kehidupan.

Cukup menaikkan semangat untuk anda?

REBECCA: William...

isteri anda dan anak

perempuan pergi lebih awal

daripada biasa pagi ini, hampir menemui saya.

Lihatlah bagaimana si kecil itu terdedah muka awak.

Adakah anda tinggal di pejabat

terlambat kerana anda takut

untuk kembali ke sisi isteri anda?

Adakah pemikiran untuk berkongsi katil dengan

orang bodoh itu sangat menjijikkan sehingga

anda kekal dalam kajian anda sampai subuh?

"Kami juga berkongsi katil bersama, William.

Dan kerana saya kini memikul beban kecuaian kita, beban

yang akan satu hari nanti juga menampakkan wajah anda.

Anda mesti tahu bahawa saya tidak boleh menanggung ini seorang diri.

Rebecca.

Ya Allah, dia mengandung."

MADELINE: Oh, Tuhanku. [terkejut] Saya tidak percaya.

EVELYN: Kita kena baca yang lagi satu.

MADELINE: Tidak! Satu setiap hari. Itu peraturannya.

[bermain muzik ngeri]

[ketukan pintu]

Hey.

Bangun. Turun ke bawah.

Apa?

MADELINE: Ini suami saya, Parker.

-Adakah anda melihat Fajar? -Maafkan saya?

Saya minta maaf mengganggu tuan. Adakah anda tahu Dawn Spooner?

Saya tidak tahu nama belakangnya, tapi ya, kita kenal dia.

COP: Sejauh manakah anda mengenalinya?

Kurang sihat.

Kami baru sahaja berpindah, sangat jarang.

Kenapa--kenapa ni?

Subuh hilang!

-Siapa awak? -Saya Kristoff.

Saya teman lelaki Dawn. Saya baru balik

dari lawatan dan tempat itu adalah kandang babi.

Baiklah. Baiklah. Bertenang.

Kami bertanya kepada jiran-jiran

jika mereka telah melihatnya.

Um, ya. Saya maksudkan, selalunya kita nampak

dia berjalan-jalan, berjalan dengan anjingnya.

COP: Adakah anda melihatnya pagi ini -atau semalam?

-Saya beritahu awak, kawan.

Dia telah pergi berhari-hari.

Tempat itu dilindungi - dalam tahi anjing.

-Tuan, adakah anda keberatan jika saya melakukan kerja saya?

Bilakah anda melihatnya terakhir?

Dua, tiga hari.

-Saya tidak tahu. -Anda lihat? Itu hari-hari.

Dia hanya berkata hari.

Adakah anda perasan apa-apa luar biasa?

-Seperti apa? -Adakah dia bertindak pelik?

Mungkin dia masuk ke dalam kereta?

Maksud saya, dia hanya pelik secara

umum tetapi tidak, tiada seperti itu.

-Mungkin dia meninggalkan bandar. -KRISTOFF: Tidak. Tidak.

Dia tidak akan pergi tanpa kambing.

Dia meninggalkan telefon bimbitnya dan ID di belakang, itulah

sebabnya kami berfikir dia mungkin masih berada di kawasan itu.

Nah, adakah anda telah mencuba ini?

Kerana mereka semua sudah berakhir tempat.

Walaupun--mereka hanya menunjuk di harta kami sekalipun.

Baiklah. Bolehkah anda berfikir apa-apa lagi?

Walaupun perkara yang paling kecil mungkin membantu.

Baik. Ada sesuatu. emm...

seseorang menceroboh masuk ke dalam rumah kami -semalam.

-Apa?

Mereka tidak--mereka tidak betul-betul menceroboh.

-Pintu terbuka luas. -Adakah anda dirompak?

Tidak. Mereka hanya merosakkan -beberapa perkara.

-Anda telah dirosakkan?

-Anda membiarkan pintu terbuka? -MADELINE: Ibu?

-Adakah anda melaporkannya? -Ya. Yeah. saya telefon.

Adakah anda menyemak rakaman?

Maksud saya, kita boleh tetapi mereka telah turun

buat sementara waktu. Saya perlukan wayar baru.

Saya ada seorang lelaki keluar untuk membetulkannya.

COP: Okay. Jika anda fikir

apa-apa lagi, anda hubungi kami, okay?

-Baik. -Saya pasti dia akan muncul.

Ayuh.

EVELYN: Awak kami dirosakkan?

-Ibu. -Anda membiarkan pintu anda terbuka?

-Ibu. -EVELYN: Ini Los Angeles.

Ini bukan Iowa.

[muzik gelap bermain]

-PARKER: & Lt; i & gt; Ia bukan dia? & lt; -MADELINE: & Lt; i & gt; Siapa itu? & lt;

-PARKER: & Lt; i & gt; Dia tidak melakukan ini -MADELINE: & Lt; i & gt; Kemudian siapa itu? & lt;

PARKER: Sayang, awak hanya ada untuk mempercayai saya, ia bukan dia

MADELINE:Apa yang sedang berlaku, Parker?

-PARKER: Ia bukan dia -

MADELINE: Apa yang berlaku di rumah ini?

Ada undang-undang.

Jika penjual tidak mendedahkan

-bahawa rumah berhantu-- -Maddy.

--mereka perlu memberi anda wang anda dikembalikan.

-Jangan mengarut. -Memang benar. Carilah.

Walaupun rumah itu mempunyai reputasi berhantu,

-mereka perlu memberitahu anda. -Rumah tidak berhantu.

Baik?

[bermain muzik ngeri]

[kanak-kanak mengekek]

GADIS: Dia mahukan awak

[kanak-kanak mengekek]

GADIS: ♪ Dia akan dapatkan awak ♪

[kanak-kanak mengekek]

GADIS: Dia akan mendapatkan kamu juga.

GADIS: & lt; i & gt; Dia akan mendapatkan anda, & lt; Parker

[pintu berderit terbuka]

[bermain muzik jahat]

[kanak-kanak ketawa dan menjerit]

Tidak!

[tercungap-cungap]

[anjing menyalak]

[telefon berdering]

-Hello? -ROB: & lt; i & gt; Di luar taman. & lt;

i & gt; -Saya fucking suka -Apa?

ROB:Halaman, i & gt; anda tidak salah

Perkara yang terbaik yang pernah anda tulis.

Saya benar-benar terpesona.

Lelaki ini luar biasa. Siapa dia?

[bermain muzik yang menegangkan]

[burung berkicauan]

[mengetuk pintu]

PARKER: Bukan sekarang! Saya sedang bekerja!

Hey. Jangan menjerit kepada saya!

-Saya perlu bekerja! -Saya tidak kisah.

Jangan sesekali menjerit kepada saya.

Maaf.

Parker, apa yang salah dengan awak?

Anda tidak boleh menyembunyikannya lagi.

Saya seperti bernafas dalam tekanan anda.

Saya boleh menghidunya pada nafas anda.

Ia berat dan ia menakutkan, dan

anda tidak bercakap dengan saya.

saya tak boleh.

Kami sepatutnya menjadi satu pasukan.

awak betul.

Ia adalah rumah ini.

Apa?

PARKER: Saya cuba menyimpannya

daripada awak, tetapi saya tidak boleh lagi.

Perkara yang mengerikan berlaku di sini.

Kenapa awak cakap macam tu?

Maddy, saya hanya mahu untuk melindungi anda.

Apa yang awak cakap ni tentang, Parker?

Dia pindah rumah.

Dia pindah rumah ni.

-William. Dia memindahkan keseluruhan ini-- -Apa? Siapa yang pindah rumah ini?

---rumah sialan untuk melarikan diri-- - Parker?

---dari dia. -Baik.

-Tapi dia jumpa mereka, okay? -Saya tidak tahu awak apa--

Shh. Shh. Dia menemui mereka.

Dia menemui mereka dan dia membunuh mereka.

- Parker? -Dia membunuhnya.

Dia membunuhnya. Dia membunuh anak kecilnya--

Kenapa awak cakap benda ni?

-Dia membunuh anak perempuan mereka. -Sekarang awak menakutkan saya!

-Maddy, Rebecca membunuh mereka! -Berhenti!

EVELYN: Maddy!

Banyak yang perlu kita lakukan. Mari pergi!

Beritahu saya ini tidak berlaku.

EVELYN: Ayuh, sayang. Jom--

Saya datang!

Bagaimana anda tahu ini?

Dia memberitahu saya.

Dia tidak mahu kita akan bersama.

WHO?

Parker, siapa?

Dia tidak boleh lari daripadanya

dan saya rasa kita juga tidak boleh.

EVELYN: Ambil buku poket saya.

-Saya tinggalkan di atas katil. -Kami bergerak.

Kami akan meninggalkan sialan ini rumah.

Kita akan keluar dari sini.

-Dia hanya akan mencari kita.

Kami akan mendapatkan wang kami kembali

dan kita akan meninggalkan rumah sialan ini.

Duit anda.

[mengeluh]

[muzik jahat gelap bermain]

[dentingan lembut logam]

[bermain muzik ngeri]

[muzik ngeri semakin kuat]

PARKER: Tidak. Tidak.

Jangan berhenti.

Tolonglah. Berhenti.

Anda tidak perlu melakukan ini.

Awak jangan--shh.

Awak boleh dapatkan saya, okay?

Awak boleh dapatkan saya.

[muzik merenung perlahan dimainkan]

Saya takkan tinggalkan awak.

Cuma jangan sakiti dia.

Saya tidak pernah mahu menyakiti sesiapa.

Saya cuma nak awak.

Awak ada saya.

[bermain muzik firasat]

[berdebar-debar]

[cengkerik berkicauan]

[Rebecca mengerang]

EVELYN: Parker?

[bermain muzik jahat]

Tidak!

EVELYN: [pada mel suara] Hai.

Tinggalkan mesejtetapi jangan terlalu lama.

Hai mak. Saya hanya mendaftar masuk.

Hanya hubungi saya bila-bila ada peluang, okay?

LELAKI: Jom dapatkan tambahan pada set.

LELAKI: Tambahan, dengan cara ini. Penampilan terakhir!

PARKER: [pada mel suara] Anda telah sampai ke Parker Brooks

-Sila tinggalkan mesej -[bip telefon]

[bermain muzik termenung]

[loceng pintu berbunyi]

DOROTHY: Ya?

Hai. Adakah anda Dorothy?

Ah, rumah Woodruff sentiasa menjadi kegemaran.

Ratu Anne sejati.

Mereka memanggilnya rumah dari Angels Flight.

Kenapa Angels Flight?

Kerana di situlah ia dibina,

di bahagian atas Angels Flight.

Dan kemudian mereka memindahkannya.

Jadi mereka betul-betul pindah rumah?

Uh-hmm. Pada tahun 1901, mereka menggunakan kuda draf.

Pada masa itu, ia sangat biasa untuk orang ramai berpindah rumah.

Adakah anda tahu mengapa mereka memindahkannya?

Uh-hmm.

Minyak.

Mereka menemui minyak pada harta itu.

Dan tiba-tiba, ada hanya derik

minyak yang besar muncul di mana-mana.

Tengok. Ini adalah gambar terakhir yang

diambil rumah sebelum mereka berpindah.

William lama baru sahaja mendapat muak dengan pandangan.

Saya fikir ia adalah kerana seorang wanita bernama Rebecca.

Adakah anda tahu siapa dia?

Oh, mereka banyak menulis artikel tentang dia.

Dia adalah anak yatim piatu.

Dia dibesarkan di rumah sebelah anda.

Dia separuh-Mexico

atau Orang Asli Amerika.

Mungkin sebabnya dia telah

ditinggalkan pada mulanya. Kasihannya.

Dia benar-benar mangsa zaman dia.

Muda, wanita yang belum berkahwin dalam

kesusahan, begitulah yang biasa mereka katakan.

-Dia mengandung. -Uh-hmm.

Tetapi dia berjaya menyembunyikannya sehingga dia keguguran atau,

dalam semua kemungkinan, dia baru sahaja menggugurkan kandungannya.

Mereka menemui mayat dalam insinerator sampah.

Dan kemudian dia membunuh diri.

Anda tahu, surat khabar sentiasa suka skandal yang baik.

Terdapat khabar angin bahawa

William Woodruff ialah bapanya.

Dan bahawa dia adalah perempuan simpanan.

-Tetapi saya tidak pernah percaya. -Mereka berbohong kepada kami.

-Saya minta maaf?

-Mereka perlu memberitahu anda perkara buruk berlaku. Ataupun, saya--

Hmm.

Saya tidak akan pernah membeli rumah itu.

Oh, ini tidak berlaku di rumah anda.

Tidak. Saya bercakap tentang pembunuhan!

-Pembunuhan? -Ya.

Isterinya, anak perempuannya.

Oh, sayang, tiada seperti itu

pernah berlaku di rumah anda.

Maksud saya, keluarga Woodruff hidup agak tua,

dan saya benar-benar melihat anak perempuan itu.

Dia datang melawat saya kira-kira 30 tahun yang lalu.

Dia berumur 80-an.

Dia adalah seorang wanita yang sangat cantik.

Adakah anda sihat?

saya...

Saya minta maaf. Saya perlu pergi.

Oh, by the way.

Adakah anda membingkainya?

Gambar pinggan Rebecca.

Ia agak rapuh.

Jika anda membingkainya, ia akan lebih selamat.

Bagaimana awak mengetahuinya tentang foto itu?

Suami awak tunjukkan pada saya.

Parker ada di sini?

Uh huh. Penulis?

Dia datang selepas awak berpindah ke sini.

Lelaki yang sangat baik.

Kamu tahu, dia sebenarnya sama

terpengaruh dengan cerita Rebecca seperti anda.

Saya perlu pergi.

[bermain muzik termenung]

Oh, Tuhanku.

FRIDA: Hai.

Saya sedang mencari Parker Brooks.

Adakah dia tinggal di sini?

kenapa?

Saya Frida Richmond.

-Adakah dia pulang? -Ada apa ini?

Nah, ini adalah perkara peribadi.

Saya isterinya.

Oh. Nah, boleh saya jumpa dia?

Bilakah anda dan Parker berkahwin?

Um, September.

Oh, dia tidak melakukannya beritahu saya dia sudah bertunang.

Saya minta maaf. siapa awak

Saya kaunselor dia.

emm...

Ahli terapi yang dilantiknya?

Parker tidak mempunyai ahli terapi.

Saya rasa saya patut bercakap dengannya.

Saya minta maaf. Adakah anda hanya...

sudikah kamu hanya beritahu saya apa yang berlaku?

Dia terlepas beberapa bulan temu janji.

Dan itu adalah satu pelanggaran perintah mahkamahnya.

Maksud awak tentang stalker dia?

Parker memberitahu anda dia ada stalker?

[bermain muzik yang menegangkan]

[berdesir kertas]

[muzik yang menegangkan diteruskan]

[bernafas terketar-ketar]

[berbunyi bip]

[muzik semakin kuat]

[jeritan tersekat-sekat]

[bernafas terketar-ketar]

[berdenting]

[menjerit] Oh, saya--

PARKER: Madeline.

-Saya tidak melakukan ini. - Parker.

-Apa yang awak dah buat? -Dengar saya.

-Tidak. -Tunggu. Tidak! Berhenti! Berhenti!

Berhenti! Berhenti! Dengar cakap saya! Dengar cakap saya!

-Tolong lepaskan saya! -Maddy, awak kena percaya saya.

-Tidak. -Ia bukan saya.

-Tidak! -Adakah anda akan berhenti?

-[Madeline menjerit] -Apa yang awak buat?

-Seseorang tolong saya! -Saya memberitahu anda.

Perkara yang dahsyat berlaku di rumah ini.

Dan mereka masih berlaku.

-[Madeline menangis] -Kenapa awak melakukan ini?

Pergi dari sini.

awak buat apa?

-Saya tidak akan menyakiti awak. -Tidak!

Saya tidak akan menyakiti awak.

-Saya tidak pernah boleh menyakiti awak. tidak pernah. -Tolong. Tolong berhenti, Parker!

Adakah anda hanya mendengar saya? Adakah anda hanya mendengar?

Dengar. Shh,shh,shh,shh.

Awak kena dengar cakap saya, Maddy.

Itu dia.

Rebecca melakukan ini.

Dia melakukan semua ini.

-MADELINE: Tidak. -Baik?

Tidak! Tidak!

Kenapa awak lari!

Adakah anda hanya menghentikannya!

-Sialan! -Jauhkan diri dari saya!

Saya dah beritahu awak! Rebecca melakukan ini!

Dia melakukan semua ini! Saya cuba menghalangnya!

[Madeline menarik nafas berat]

Oh, Tuhanku.

[muzik gelap bermain]

Orang tak ada wujud menjadi nyata.

Sakit itu nyata.

[api berbunyi]

Rahsia adalah nyata.

[Rebecca menjerit]

Saya menyimpan milik saya terkubur terlalu lama.

Dan mereka bernanah.

Dan mereka tumbuh dalam diri saya.

Tidak. [menangis]

Dan mereka keluar.

[bermain muzik yang menegangkan]

[Madeline menangis teresak-esak]

Dan mereka memakan awak hidup-hidup.

siapa awak

Satu-satunya cara saya boleh selamatkan awak adalah untuk bersamanya.

Kamu gila!

[muzik jahat gelap bermain]

Oh tidak.

Tolong! Tolonglah!

Seseorang tolong kami! [menangis]

Tolong saya!

Tolong bantu! Tolong! [menangis]

Tolonglah!

Tolonglah! Tolonglah! Tolonglah!

[bermain muzik yang menegangkan]

-[berdentum] -[wanita mengerang]

[muzik yang menegangkan diteruskan]

[pistol ayam jantan]

Saya tidak gila.

-[tembakan] -[merengus]

[Madeline menjerit]

Tolonglah. Tolonglah.

Dia milik saya.

[tembakan]

[merengus]

[jerit]

[tembakan]

[teresak-esak]

-[main muzik firasat] -[menangis]

[bualan radio yang tidak jelas]

[siren polis meraung]

[siren meraung di kejauhan]

REBECCA: Untuk Satu Cinta Sejati Saya

Kita semua ada rahsia kita mengunci dalam gelap.

Tetapi apabila rahsia kita

menjadi begitu luas, begitu

tidak terbatas, mereka melarikan diri.

Dan hantarkan jiwa kami dalam kegelapan.

Kemudian rahsia menjadi satu-satunya kebenaran kita.

REBECCA DAN PARKER: & Lt; i & gt; Tetapi

malangnya, sayangku, & lt; i & gt; tiada rahsia lagi.

REBECCA DAN PARKER: Dan kami bersama-sama sebagai satu

Dan di rumah ini,

kita akan tinggal.

Selamanya.

Hai sayang.

Lihat ini.

Apa? Keluar dari sini.

-Yeah. Ia berada di loteng. -Itu menakjubkan.

Ianya cantik.

[hon kereta berbunyi]

-Penggerak ada di sini. -Yeah.

Hey.

Apa?

Kita berjaya.

Bab baru.

Selamat pulang.

[kedua-duanya tergelak kecil]

[mengeluh]

Saya tertanya-tanya siapa dia.

Oh, boleh awak letakkan itu di dapur, tolong?

Terima kasih kawan-kawan.

[muzik firasat gelap bermain]

Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.